document.addEventListener('DOMContentLoaded', () => {
  const form = document.getElementById('playlist-form');
  const container = document.getElementById('playlist-container');
  
  // Load saved playlists from localStorage
  let playlists = JSON.parse(localStorage.getItem('playlists')) || [];
  
  // Render existing playlists
  renderPlaylists();
  
  form.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const title = document.getElementById('playlist-title').value;
    const url = document.getElementById('playlist-url').value;
    
    addPlaylist(title, url);
    form.reset();
  });
  
  function addPlaylist(title, url) {
    const playlist = {
      id: Date.now(),
      title,
      url,
      completed: false
    };
    
    playlists.unshift(playlist);
    saveToLocalStorage();
    renderPlaylists();
  }
  
  function renderPlaylists() {
    container.innerHTML = '';
    
    playlists.forEach(playlist => {
      const element = document.createElement('div');
      element.className = `playlist-item ${playlist.completed ? 'completed' : ''}`;
      
      element.innerHTML = `
        <div class="playlist-info">
          <div class="playlist-title">${playlist.title}</div>
          <a href="${playlist.url}" class="playlist-url" target="_blank" rel="noopener noreferrer">
            ${playlist.url}
          </a>
        </div>
        <button class="btn-complete" onclick="toggleComplete(${playlist.id})">
          ${playlist.completed ? '✓ Completed' : 'Mark Complete'}
        </button>
      `;
      
      container.appendChild(element);
    });
  }
  
  // Make toggleComplete available globally
  window.toggleComplete = function(id) {
    const playlist = playlists.find(p => p.id === id);
    if (playlist) {
      playlist.completed = !playlist.completed;
      saveToLocalStorage();
      renderPlaylists();
    }
  }
  
  function saveToLocalStorage() {
    localStorage.setItem('playlists', JSON.stringify(playlists));
  }
});
